<?xml version="1.0" encoding="UTF-8"?>
<rss xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" version="2.0">
  <channel>
    <title>topic Try to place the content of in OpenCL* for CPU</title>
    <link>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051908#M4050</link>
    <description>&lt;P&gt;Try to place the content of the main.h header file inside your kernel.cl file: I think what is going on is that when you compile your program, the compiler does not see your header file. Use -I option to the compiler (pass it to clBuildProgram) to point to the right directory where your header file will reside.&lt;/P&gt;</description>
    <pubDate>Tue, 11 Nov 2014 03:10:10 GMT</pubDate>
    <dc:creator>Robert_I_Intel</dc:creator>
    <dc:date>2014-11-11T03:10:10Z</dc:date>
    <item>
      <title>Problem:Unable to pass structure to a opencl kernel</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051905#M4047</link>
      <description>&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;Unable to pass structure to a opencl kernel?&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&lt;STRONG style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; font-family: inherit; font-size: 13px; font-style: inherit; font-weight: bold; vertical-align: baseline;"&gt;main.h&lt;/STRONG&gt;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;typedef struct _Point&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;{&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp; unsigned int x;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp; unsigned int y;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;}mPoint;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; height: 8pt; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; min-height: 8pt; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&lt;STRONG style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; font-family: inherit; font-size: 13px; font-style: inherit; font-weight: bold; vertical-align: baseline;"&gt;kernel.cl:&lt;/STRONG&gt;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;#include"main.h"&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;__kernel void Fun(__global struct mPoint* p)&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;{&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; unsigned int tid = get_local_id(0);&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp; p-&amp;gt;x=tid;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;}&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; height: 8pt; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; min-height: 8pt; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&lt;STRONG style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; font-family: inherit; font-size: 13px; font-style: inherit; font-weight: bold; vertical-align: baseline;"&gt;The error returned by clBuildProgram():&lt;/STRONG&gt;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;clBuild failed:-11&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;Compilation started&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;1:3:38: warning: declaration of 'struct mPoint' will not be visible outside of t&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;his function&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;1:6:3: error: incomplete definition of type 'struct mPoint'&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;1:3:38: note: forward declaration of 'struct mPoint'&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;Compilation failed&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; height: 8pt; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; min-height: 8pt; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&amp;nbsp;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&lt;SPAN style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; color: rgb(67, 67, 67); font-family: Tahoma, Arial; font-size: 12px; font-style: inherit; font-weight: inherit; vertical-align: baseline; background-color: rgb(242, 242, 242);"&gt;&lt;STRONG style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; font-family: inherit; font-size: 12px; font-style: inherit; font-weight: bold; vertical-align: baseline;"&gt;I don't known where is the mistake.&lt;/STRONG&gt;&lt;/SPAN&gt;&lt;/P&gt;

&lt;P style="font: 13px/19px &amp;quot;Helvetica Neue&amp;quot;, Helvetica, Arial, &amp;quot;Lucida Grande&amp;quot;, sans-serif; margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; text-align: left; color: rgb(51, 51, 51); text-transform: none; text-indent: 0px; letter-spacing: normal; word-spacing: 0px; vertical-align: baseline; white-space: normal; font-size-adjust: none; font-stretch: normal; background-color: rgb(255, 255, 255); -webkit-text-stroke-width: 0px;"&gt;&lt;SPAN style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; color: rgb(67, 67, 67); font-family: Tahoma, Arial; font-size: 12px; font-style: inherit; font-weight: inherit; vertical-align: baseline; background-color: rgb(242, 242, 242);"&gt;&lt;STRONG style="margin: 0px; padding: 0px; border: 0px currentColor; border-image: none; font-family: inherit; font-size: 12px; font-style: inherit; font-weight: bold; vertical-align: baseline;"&gt;Thanks.&lt;/STRONG&gt;&lt;/SPAN&gt;&lt;/P&gt;</description>
      <pubDate>Mon, 10 Nov 2014 09:11:07 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051905#M4047</guid>
      <dc:creator>明_王_</dc:creator>
      <dc:date>2014-11-10T09:11:07Z</dc:date>
    </item>
    <item>
      <title>You should change __kernel</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051906#M4048</link>
      <description>&lt;P&gt;You should change __kernel void Fun(__global struct mPoint* p) definition.&lt;/P&gt;

&lt;P&gt;The best way to fix your issue is to remove 'struct':&lt;/P&gt;

&lt;P&gt;__kernel void Fun(__global mPoint* p)&lt;/P&gt;</description>
      <pubDate>Mon, 10 Nov 2014 09:29:52 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051906#M4048</guid>
      <dc:creator>Alexey_B_Intel1</dc:creator>
      <dc:date>2014-11-10T09:29:52Z</dc:date>
    </item>
    <item>
      <title> </title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051907#M4049</link>
      <description>&lt;P&gt;&amp;nbsp;&lt;/P&gt;

&lt;P&gt;&lt;STRONG&gt;&lt;SPAN style="font-size: 12px; line-height: 18px;"&gt;I removed 'struct', h&lt;/SPAN&gt;owever, another question emerged:&lt;/STRONG&gt;&lt;/P&gt;

&lt;P&gt;error: must use 'struct' tag to refer to type '&lt;SPAN style="font-size: 12px; line-height: 18px;"&gt;mPoint&lt;/SPAN&gt;'&lt;BR /&gt;
	&lt;SPAN style="font-size: 12px; line-height: 18px;"&gt;&amp;nbsp;__kernel void Fun(__global mPoint* p)&amp;nbsp;&lt;/SPAN&gt;&lt;BR /&gt;
	&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp;^&lt;BR /&gt;
	&amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; &amp;nbsp; struct&amp;nbsp;&lt;/P&gt;</description>
      <pubDate>Tue, 11 Nov 2014 02:12:09 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051907#M4049</guid>
      <dc:creator>明_王_</dc:creator>
      <dc:date>2014-11-11T02:12:09Z</dc:date>
    </item>
    <item>
      <title>Try to place the content of</title>
      <link>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051908#M4050</link>
      <description>&lt;P&gt;Try to place the content of the main.h header file inside your kernel.cl file: I think what is going on is that when you compile your program, the compiler does not see your header file. Use -I option to the compiler (pass it to clBuildProgram) to point to the right directory where your header file will reside.&lt;/P&gt;</description>
      <pubDate>Tue, 11 Nov 2014 03:10:10 GMT</pubDate>
      <guid>https://community.intel.com/t5/OpenCL-for-CPU/Problem-Unable-to-pass-structure-to-a-opencl-kernel/m-p/1051908#M4050</guid>
      <dc:creator>Robert_I_Intel</dc:creator>
      <dc:date>2014-11-11T03:10:10Z</dc:date>
    </item>
  </channel>
</rss>

